==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/kmfwidgets/kmfchecklistitem.h <==
//
// C++ Interface: kmfchecklistitem
//
// Description: 
//
//
// Author: Christian Hubinger <chubinger@gmail.com>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFCHECKLISTITEM_H
#define KMFCHECKLISTITEM_H

#include <qlistview.h>
#include <kdemacros.h>

class KMFProtocol;
class NetfilterObject;

class KDE_EXPORT KMFCheckListItem : public QCheckListItem
{
public:
	KMFCheckListItem( QListViewItem *parent, const QString&, Type tt = Controller, NetfilterObject* = 0 );
	KMFCheckListItem( QListView *parent, QListViewItem *after, const QString&, Type tt = Controller, NetfilterObject* = 0 );
	KMFCheckListItem( QListViewItem *parent, QListViewItem *after, const QString&, Type tt = Controller, NetfilterObject* = 0);
    ~KMFCheckListItem();


public:
	KMFProtocol* protocol() const {
		return m_protocol;
	};

private:
	void loadNetfilterObject( NetfilterObject* );

	KMFProtocol *m_protocol;
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/kmfwidgets/kmfchecklistitem.h <==
//
// C++ Interface: kmfchecklistitem
//
// Description: 
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFCHECKLISTITEM_H
#define KMFCHECKLISTITEM_H

#include <qlistview.h>
#include <kdemacros.h>

namespace KMF {
class KMFProtocol;
class KMFProtocolUsage;
class NetfilterObject;

class KDE_EXPORT KMFCheckListItem : public QCheckListItem
{
public:
	KMFCheckListItem( QListViewItem *parent, const QString&, Type tt = Controller, KMFProtocolUsage* = 0 );
	KMFCheckListItem( QListView *parent, QListViewItem *after, const QString&, Type tt = Controller, KMFProtocolUsage* = 0 );
	KMFCheckListItem( QListViewItem *parent, QListViewItem *after, const QString&, Type tt = Controller, KMFProtocolUsage* = 0);
    ~KMFCheckListItem();


public:
	KMFProtocolUsage* protocolUsage() const {
		return m_protocolUsage;
	};

private:
	void loadKMFProtocolUsage( KMFProtocolUsage* );

	KMFProtocolUsage *m_protocolUsage;
};
}
#endif
